@@ -42,6 +42,19 @@ html_parser_emit_new_node (HtmlParser *parser, DomNode *node)
 	g_signal_emit (G_OBJECT (parser), parser_signals [NEW_NODE], 0, node);
 }
 
+static void 
+html_comment (void *ctx, const xmlChar *ch)
+{
+	HtmlParser *parser = HTML_PARSER(ctx);
+	DomNode *node;
+
+	comment (parser->xmlctxt, ch);
+
+	node = dom_Node_mkref (xmlGetLastChild (parser->xmlctxt->node));
+
+	html_parser_emit_new_node (parser, node);
+}
+
 static void
 html_characters (void *ctx, const xmlChar *ch, int len)
 {
@@ -97,8 +110,6 @@ html_endDocument (void *ctx)
 	HtmlParser *parser = HTML_PARSER (ctx);
 	
 	endDocument (parser->xmlctxt);
-	
-	g_print ("Document has ended\n");
 }
 
 xmlSAXHandler SAXHandlerStruct = {
@@ -122,7 +133,7 @@ xmlSAXHandler SAXHandlerStruct = {
     html_characters, /* characters */
     NULL, /* ignorableWhitespace */
     NULL, /* processingInstruction */
-    NULL, /* comment */
+    html_comment, /* comment */
     NULL, /* xmlParserWarning */
     NULL, /* xmlParserError */
     NULL, /* xmlParserError */
