@@ -5,6 +5,7 @@
 #include "dom-node.h"
 #include "dom-attr.h"
 #include "dom-document.h"
+#include "dom-comment.h"
 #include "dom-element.h"
 #include "dom-text.h"
 #include "dom-nodelist.h"
@@ -86,6 +87,9 @@ dom_Node_mkref (xmlNode *node)
 	case XML_ENTITY_DECL:
 		result = g_object_new (DOM_TYPE_ENTITY, NULL);
 		break;
+	case XML_COMMENT_NODE:
+		result = g_object_new (DOM_TYPE_COMMENT, NULL);
+		break;
 	default:
 		g_warning ("Unknown node type: %d\n", node->type);
 		return NULL;
