@@ -261,7 +261,6 @@ pre_convert_whitespace (guchar *text, int length, gint line_offset, gint *out_le
 	}
 	res = g_malloc (length + (8 * num_tabs));
 	dst = res;
-	g_print ("num_tabs = %d offset = %d\n", num_tabs, line_offset);
 
 	while (text != end) {
 		if (*text == '\t') {
@@ -715,12 +714,11 @@ html_box_text_get_len (HtmlBoxText *box)
 gchar *
 html_box_text_get_text (HtmlBoxText *box, int *text_len)
 {
-	g_error ("NYI get_text()");
-	return NULL;
-#if 0
-	*text_len = box->length;
+	g_return_if_fail (box != NULL);
+
+	if (text_len)
+		*text_len = box->length;
 	return box->canon_text;
-#endif
 }
 
 gboolean
@@ -916,6 +914,37 @@ html_box_text_get_index (HtmlBoxText *text, gint x_pos)
 	return index;
 }
 
+void
+html_box_text_get_character_extents (HtmlBoxText *text, gint index, GdkRectangle *rect)
+{
+	if (rect) {
+		gint width1, width2;
+		HtmlBox *box;
+
+		box = HTML_BOX (text);
+		pango_glyph_string_index_to_x (text->glyphs,
+					       text->canon_text,
+					       text->length,
+					       &text->item_data->item->analysis,
+					       index,
+					       FALSE,
+					       &width1);
+		pango_glyph_string_index_to_x (text->glyphs,
+					       text->canon_text,
+					       text->length,
+					       &text->item_data->item->analysis,
+					       index + 1,
+					       FALSE,
+					       &width2);
+		width1 /= PANGO_SCALE;
+		width2 /= PANGO_SCALE;
+		rect->x = box->x + width1;
+		rect->width = width2 - width1;
+		rect->y = box->y;
+		rect->height = box->height;
+	}
+}
+
 static gint
 html_box_text_get_bidi_level (HtmlBox *box)
 {
